# -*- coding: utf-8 -*-
# Copyright 2024 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from google.cloud.securitycenter_v2 import gapic_version as package_version

__version__ = package_version.__version__


from .services.security_center import SecurityCenterAsyncClient, SecurityCenterClient
from .types.access import Access, Geolocation, ServiceAccountDelegationInfo
from .types.application import Application
from .types.attack_exposure import AttackExposure
from .types.attack_path import AttackPath
from .types.backup_disaster_recovery import BackupDisasterRecovery
from .types.bigquery_export import BigQueryExport
from .types.cloud_armor import (
    AdaptiveProtection,
    Attack,
    CloudArmor,
    Requests,
    SecurityPolicy,
)
from .types.cloud_dlp_data_profile import CloudDlpDataProfile
from .types.cloud_dlp_inspection import CloudDlpInspection
from .types.compliance import Compliance
from .types.connection import Connection
from .types.contact_details import Contact, ContactDetails
from .types.container import Container
from .types.data_access_event import DataAccessEvent
from .types.data_flow_event import DataFlowEvent
from .types.data_retention_deletion_event import DataRetentionDeletionEvent
from .types.database import Database
from .types.disk import Disk
from .types.exfiltration import ExfilResource, Exfiltration
from .types.external_system import ExternalSystem
from .types.file import File
from .types.finding import Finding
from .types.folder import Folder
from .types.group_membership import GroupMembership
from .types.iam_binding import IamBinding
from .types.indicator import Indicator
from .types.kernel_rootkit import KernelRootkit
from .types.kubernetes import Kubernetes
from .types.label import Label
from .types.load_balancer import LoadBalancer
from .types.log_entry import CloudLoggingEntry, LogEntry
from .types.mitre_attack import MitreAttack
from .types.mute_config import MuteConfig
from .types.notebook import Notebook
from .types.notification_config import NotificationConfig
from .types.notification_message import NotificationMessage
from .types.org_policy import OrgPolicy
from .types.process import EnvironmentVariable, Process
from .types.resource import (
    AwsMetadata,
    AzureMetadata,
    CloudProvider,
    GcpMetadata,
    Resource,
    ResourcePath,
)
from .types.resource_value_config import ResourceValue, ResourceValueConfig
from .types.security_marks import SecurityMarks
from .types.security_posture import SecurityPosture
from .types.securitycenter_service import (
    BatchCreateResourceValueConfigsRequest,
    BatchCreateResourceValueConfigsResponse,
    BulkMuteFindingsRequest,
    BulkMuteFindingsResponse,
    CreateBigQueryExportRequest,
    CreateFindingRequest,
    CreateMuteConfigRequest,
    CreateNotificationConfigRequest,
    CreateResourceValueConfigRequest,
    CreateSourceRequest,
    DeleteBigQueryExportRequest,
    DeleteMuteConfigRequest,
    DeleteNotificationConfigRequest,
    DeleteResourceValueConfigRequest,
    GetBigQueryExportRequest,
    GetMuteConfigRequest,
    GetNotificationConfigRequest,
    GetResourceValueConfigRequest,
    GetSimulationRequest,
    GetSourceRequest,
    GetValuedResourceRequest,
    GroupFindingsRequest,
    GroupFindingsResponse,
    GroupResult,
    ListAttackPathsRequest,
    ListAttackPathsResponse,
    ListBigQueryExportsRequest,
    ListBigQueryExportsResponse,
    ListFindingsRequest,
    ListFindingsResponse,
    ListMuteConfigsRequest,
    ListMuteConfigsResponse,
    ListNotificationConfigsRequest,
    ListNotificationConfigsResponse,
    ListResourceValueConfigsRequest,
    ListResourceValueConfigsResponse,
    ListSourcesRequest,
    ListSourcesResponse,
    ListValuedResourcesRequest,
    ListValuedResourcesResponse,
    SetFindingStateRequest,
    SetMuteRequest,
    UpdateBigQueryExportRequest,
    UpdateExternalSystemRequest,
    UpdateFindingRequest,
    UpdateMuteConfigRequest,
    UpdateNotificationConfigRequest,
    UpdateResourceValueConfigRequest,
    UpdateSecurityMarksRequest,
    UpdateSourceRequest,
)
from .types.simulation import Simulation
from .types.source import Source
from .types.toxic_combination import ToxicCombination
from .types.valued_resource import ResourceValueConfigMetadata, ValuedResource
from .types.vulnerability import (
    Cve,
    Cvssv3,
    Package,
    Reference,
    SecurityBulletin,
    Vulnerability,
)

__all__ = (
    "SecurityCenterAsyncClient",
    "Access",
    "AdaptiveProtection",
    "Application",
    "Attack",
    "AttackExposure",
    "AttackPath",
    "AwsMetadata",
    "AzureMetadata",
    "BackupDisasterRecovery",
    "BatchCreateResourceValueConfigsRequest",
    "BatchCreateResourceValueConfigsResponse",
    "BigQueryExport",
    "BulkMuteFindingsRequest",
    "BulkMuteFindingsResponse",
    "CloudArmor",
    "CloudDlpDataProfile",
    "CloudDlpInspection",
    "CloudLoggingEntry",
    "CloudProvider",
    "Compliance",
    "Connection",
    "Contact",
    "ContactDetails",
    "Container",
    "CreateBigQueryExportRequest",
    "CreateFindingRequest",
    "CreateMuteConfigRequest",
    "CreateNotificationConfigRequest",
    "CreateResourceValueConfigRequest",
    "CreateSourceRequest",
    "Cve",
    "Cvssv3",
    "DataAccessEvent",
    "DataFlowEvent",
    "DataRetentionDeletionEvent",
    "Database",
    "DeleteBigQueryExportRequest",
    "DeleteMuteConfigRequest",
    "DeleteNotificationConfigRequest",
    "DeleteResourceValueConfigRequest",
    "Disk",
    "EnvironmentVariable",
    "ExfilResource",
    "Exfiltration",
    "ExternalSystem",
    "File",
    "Finding",
    "Folder",
    "GcpMetadata",
    "Geolocation",
    "GetBigQueryExportRequest",
    "GetMuteConfigRequest",
    "GetNotificationConfigRequest",
    "GetResourceValueConfigRequest",
    "GetSimulationRequest",
    "GetSourceRequest",
    "GetValuedResourceRequest",
    "GroupFindingsRequest",
    "GroupFindingsResponse",
    "GroupMembership",
    "GroupResult",
    "IamBinding",
    "Indicator",
    "KernelRootkit",
    "Kubernetes",
    "Label",
    "ListAttackPathsRequest",
    "ListAttackPathsResponse",
    "ListBigQueryExportsRequest",
    "ListBigQueryExportsResponse",
    "ListFindingsRequest",
    "ListFindingsResponse",
    "ListMuteConfigsRequest",
    "ListMuteConfigsResponse",
    "ListNotificationConfigsRequest",
    "ListNotificationConfigsResponse",
    "ListResourceValueConfigsRequest",
    "ListResourceValueConfigsResponse",
    "ListSourcesRequest",
    "ListSourcesResponse",
    "ListValuedResourcesRequest",
    "ListValuedResourcesResponse",
    "LoadBalancer",
    "LogEntry",
    "MitreAttack",
    "MuteConfig",
    "Notebook",
    "NotificationConfig",
    "NotificationMessage",
    "OrgPolicy",
    "Package",
    "Process",
    "Reference",
    "Requests",
    "Resource",
    "ResourcePath",
    "ResourceValue",
    "ResourceValueConfig",
    "ResourceValueConfigMetadata",
    "SecurityBulletin",
    "SecurityCenterClient",
    "SecurityMarks",
    "SecurityPolicy",
    "SecurityPosture",
    "ServiceAccountDelegationInfo",
    "SetFindingStateRequest",
    "SetMuteRequest",
    "Simulation",
    "Source",
    "ToxicCombination",
    "UpdateBigQueryExportRequest",
    "UpdateExternalSystemRequest",
    "UpdateFindingRequest",
    "UpdateMuteConfigRequest",
    "UpdateNotificationConfigRequest",
    "UpdateResourceValueConfigRequest",
    "UpdateSecurityMarksRequest",
    "UpdateSourceRequest",
    "ValuedResource",
    "Vulnerability",
)
